@@ -128,6 +128,7 @@ model_data <- function(x){
 #' model_data(pmodel) %>%
 #'  construct_model_points(exposure = exposure, exposure_by = jaar) %>%
 #'  add_prediction(., pmodel)
+#'  }
 #'
 #' @export
 construct_model_points <- function(x, exposure = NULL, exposure_by = NULL,
@@ -150,6 +151,7 @@ construct_model_points <- function(x, exposure = NULL, exposure_by = NULL,
       stop("Input must be of class model_data, use model_data() to create data",
            call. = FALSE)
     }
+    offweights <- NULL
     xdf <- data.frame(xdf)
     premium_nm <- setdiff(names(xdf), c(aggcols0, exposure_nm, exposure_by_nm))
     premium_df <- xdf[, premium_nm, drop = FALSE]
@@ -207,47 +209,40 @@ construct_model_points <- function(x, exposure = NULL, exposure_by = NULL,
       }
     }
 
-
     if ( exposure_by_nm != "NULL" ){
 
       if (length(aggcols0) == 0){
+
         xdt_agg0 <- xdf[
           , .(count = .N), by = c(premium_nm, exposure_by_nm)][
             , (exposure_by_nm) := paste0("count_", get(exposure_by_nm))]
 
-        f <- as.formula(paste0(paste0(premium_nm, collapse = " + "), "~ ",
-                               paste(exposure_by_nm)))
-
+        f <- construct_fm(premium_nm, exposure_by_nm)
         xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = "count")
       }
 
       if (length(aggcols0) > 0){
-        xdt_agg0 <- xdf[, c(.N, lapply(.SD, sum, na.rm = TRUE)),
-                        by = c(premium_nm, exposure_by_nm), .SDcols = aggcols0][
-                          , (exposure_by_nm) := paste0("count_",
-                                                       get(exposure_by_nm))]
-        data.table::setnames(xdt_agg0, old = "N", new = "count")
+        xdt_agg0 <- xdf[
+          , c(.N, lapply(.SD, sum, na.rm = TRUE)), by =
+            c(premium_nm, exposure_by_nm), .SDcols = aggcols0][
+              , (exposure_by_nm) := paste0("count_", get(exposure_by_nm))]
 
-        f <- as.formula(paste0(paste0(c(premium_nm, aggcols0),
-                                      collapse = " + "), "~ ",
-                               paste(exposure_by_nm)))
-
-        xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = "count")
+        f <- construct_fm(c(premium_nm, aggcols0), exposure_by_nm)
+        xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = "N")
       }
     }
 
     xdt_agg <- data.frame(xdt_agg)
   }
 
-
   if ( exposure_nm != "NULL" ){
     xdf <- data.table::data.table(xdf)
 
     if ( exposure_by_nm == "NULL" ){
+
       if (length(aggcols0) == 0){
-        xdt_agg <- xdf[, .(count = sum(get(exposure_nm), na.rm = TRUE)),
-                       by = premium_nm]
-        data.table::setnames(xdt_agg, old = "count", new = exposure_nm)
+        xdt_agg <- xdf[, lapply(.SD, sum, na.rm = TRUE), by = premium_nm,
+                       .SDcols = exposure_nm]
       }
 
       if ( length(aggcols0) > 0 ){
@@ -258,50 +253,39 @@ construct_model_points <- function(x, exposure = NULL, exposure_by = NULL,
 
     if ( exposure_by_nm != "NULL" ){
 
-
       if (length(aggcols0) == 0){
 
         xdt_agg0 <- xdf[
-          , lapply(.SD, sum, na.rm = TRUE),
-          by = c(premium_nm, exposure_by_nm),
-          .SDcols = exposure_nm][
+          , lapply(.SD, sum, na.rm = TRUE), by =
+            c(premium_nm, exposure_by_nm), .SDcols = exposure_nm][
             , (exposure_by_nm) := paste0(exposure_nm, "_", get(exposure_by_nm))]
 
-        f <- as.formula(paste0(paste0(premium_nm, collapse = " + "), "~ ",
-                               paste(exposure_by_nm)))
+        f <- construct_fm(premium_nm, exposure_by_nm)
+        xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = exposure_nm)
       }
 
       if (length(aggcols0) > 0){
 
-        aggcols01 <- aggcols0
-        if ( isTRUE(offweights %in% aggcols0)) {
-          aggcols01 <- aggcols0[aggcols0 != offweights]
-        }
-
         xdt_agg0 <- xdf[
           , lapply(.SD, sum, na.rm = TRUE), by = c(premium_nm, exposure_by_nm),
           .SDcols = c(aggcols0, exposure_nm)][
             , (exposure_by_nm) := paste0(exposure_nm, "_", get(exposure_by_nm))]
 
-        f <- as.formula(paste0(paste0(c(premium_nm),
-                                      collapse = " + "), "~ ",
-                               paste(exposure_by_nm)))
+        f <- construct_fm(premium_nm, exposure_by_nm)
+        xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = exposure_nm)
 
         if ( isTRUE(offweights %in% aggcols0)) {
           xdt_ext <- xdt_agg0[, lapply(.SD, sum, na.rm = TRUE), by = premium_nm,
                               .SDcols = aggcols0]
+          xdt_agg <- merge(xdt_agg, xdt_ext, all.x = TRUE)
         }
       }
-
-      xdt_agg <- data.table::dcast(xdt_agg0, f, value.var = exposure_nm)
-
-      if ( isTRUE(offweights %in% aggcols0)) {
-        xdt_agg <- merge(xdt_agg, xdt_ext, all.x = TRUE)
-      }
     }
 
-    data.table::setnames(xdt_agg, old = offweights,
+    if( inherits(x, c("model_data")) ) {
+      data.table::setnames(xdt_agg, old = offweights,
                          new = gsub('_99$', '', offweights))
+    }
     xdt_agg <- data.frame(xdt_agg)
   }
 
@@ -318,12 +302,10 @@ construct_model_points <- function(x, exposure = NULL, exposure_by = NULL,
 
   refinement_df <- NULL
   if( inherits(x, c("model_data")) ) {
-    old_nm <- attr(x, "old_nm")
-    new_nm <- attr(x, "new_nm")
-    df <- data.frame(old_nm, new_nm)
-    xdf <- x
-    refinement_nm <- lapply(split(df, seq_len(nrow(df))), as.character)
-    refinement_df <- lapply(refinement_nm, function(x) xdf[, x, drop = FALSE])
+    mgd_rst <- attr(x, "mgd_rst")
+    mgd_smt <- attr(x, "mgd_smt")
+    refinement_nm <- append(mgd_rst, mgd_smt)
+    refinement_df <- lapply(refinement_nm, function(y) x[, y, drop = FALSE])
     refinement_df <- lapply(refinement_df, unique)
   }
 
